==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive.md <==
# AmazonSimpleStorageServiceGlacierArchive


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')
```



| Illustration | AmazonSimpleStorageServiceGlacierArchive | AmazonSimpleStorageServiceGlacierArchiveCard | AmazonSimpleStorageServiceGlacierArchiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive.png) | ![illustration for AmazonSimpleStorageServiceGlacierArchive](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierArchiveCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchiveCard.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierArchiveGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchiveGroup.Local.png) |




## AmazonSimpleStorageServiceGlacierArchive

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchive
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchive('AmazonSimpleStorageServiceGlacierArchive', 'Amazon Simple Storage Service Glacier Archive', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchive
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchive('AmazonSimpleStorageServiceGlacierArchive', 'Amazon Simple Storage Service Glacier Archive', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceGlacierArchiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveCard('AmazonSimpleStorageServiceGlacierArchiveCard', 'Amazon Simple Storage Service Glacier Archive Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveCard('AmazonSimpleStorageServiceGlacierArchiveCard', 'Amazon Simple Storage Service Glacier Archive Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceGlacierArchiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveGroup('AmazonSimpleStorageServiceGlacierArchiveGroup', 'Amazon Simple Storage Service Glacier Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveGroup('AmazonSimpleStorageServiceGlacierArchiveGroup', 'Amazon Simple Storage Service Glacier Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive.md <==
# AmazonSimpleStorageServiceGlacierArchive


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')
```



| Illustration | AmazonSimpleStorageServiceGlacierArchive | AmazonSimpleStorageServiceGlacierArchiveCard | AmazonSimpleStorageServiceGlacierArchiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive.png) | ![illustration for AmazonSimpleStorageServiceGlacierArchive](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierArchiveCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchiveCard.Local.png) | ![illustration for AmazonSimpleStorageServiceGlacierArchiveGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchiveGroup.Local.png) |




## AmazonSimpleStorageServiceGlacierArchive

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchive
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchive('AmazonSimpleStorageServiceGlacierArchive', 'Amazon Simple Storage Service Glacier Archive', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchive
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchive('AmazonSimpleStorageServiceGlacierArchive', 'Amazon Simple Storage Service Glacier Archive', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceGlacierArchiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveCard('AmazonSimpleStorageServiceGlacierArchiveCard', 'Amazon Simple Storage Service Glacier Archive Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveCard('AmazonSimpleStorageServiceGlacierArchiveCard', 'Amazon Simple Storage Service Glacier Archive Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceGlacierArchiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveGroup('AmazonSimpleStorageServiceGlacierArchiveGroup', 'Amazon Simple Storage Service Glacier Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceGlacierArchiveGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceGlacierArchive')

' renders the element
AmazonSimpleStorageServiceGlacierArchiveGroup('AmazonSimpleStorageServiceGlacierArchiveGroup', 'Amazon Simple Storage Service Glacier Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
